========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - | |travis|
        |
    * - package
      - | |version| |wheel| |supported-versions| |supported-implementations|


.. |docs| image:: https://readthedocs.org/projects/mario-addons/badge/?style=flat
    :target: https://readthedocs.org/projects/mario-addons
    :alt: Documentation Status


.. |travis| image:: https://travis-ci.com/python-mario/mario-addons.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.com/python-mario/mario-addons


.. |version| image:: https://img.shields.io/pypi/v/mario-addons.svg
    :alt: PyPI Package latest release
    :target: https://pypi.org/pypi/mario-addons


.. |wheel| image:: https://img.shields.io/pypi/wheel/mario-addons.svg
    :alt: PyPI Wheel
    :target: https://pypi.org/pypi/mario-addons

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/mario-addons.svg
    :alt: Supported versions
    :target: https://pypi.org/pypi/mario-addons

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/mario-addons.svg
    :alt: Supported implementations
    :target: https://pypi.org/pypi/mario-addons


.. end-badges

Contributed commands for `Mario <https://python-mario.readthedocs.org>`__



Installation
============

::

    pip install mario-addons

Documentation
=============

* Mario: https://python-mario.readthedocs.io/
* Mario addons: https://mario-addons.readthedocs.io/
